;;; misc.el --- miscellaneous functions for XEmacs

;; Copyright (C) 1989, 1997 Free Software Foundation, Inc.

;; Maintainer: FSF
;; Keywords: extensions, dumped

;; This file is part of XEmacs.

;; XEmacs is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; XEmacs is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with XEmacs; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
;; 02111-1307, USA.

;;; Synched up with: FSF 19.34.

;;; Commentary:

;; This file is dumped with XEmacs.

;; 06/11/1997 - Use char-(after|before) instead of
;;  (following|preceding)-char. -slb

;;; Code:

(defun copy-from-above-command (&optional arg)
  "Copy characters from previous nonblank line, starting just above point.
Copy ARG characters, but not past the end of that line.
If no argument given, copy the entire rest of the line.
The characters copied are inserted in the buffer before point."
  (interactive "P")
  (let ((cc (current-column))
	n
	(string ""))
    (save-excursion
      (beginning-of-line)
      (backward-char 1)
      (skip-chars-backward "\ \t\n")
      (move-to-column cc)
      ;; Default is enough to copy the whole rest of the line.
      (setq n (if arg (prefix-numeric-value arg) (point-max)))
      ;; If current column winds up in middle of a tab,
      ;; copy appropriate number of "virtual" space chars.
      (if (< cc (current-column))
	  (if (eq (char-before (point)) ?\t)
	      (progn
		(setq string (make-string (min n (- (current-column) cc)) ?\ ))
		(setq n (- n (min n (- (current-column) cc)))))
	    ;; In middle of ctl char => copy that whole char.
	    (backward-char 1)))
      (setq string (concat string
			   (buffer-substring
			    (point)
			    (min (save-excursion (end-of-line) (point))
				 (+ n (point)))))))
    (insert string)))

;;;
;; user interface to line-move-visual and word wrap.
;; The only reason this is here is that it has to be loaded after modeline,
;; and I can't think where to put it.
(defvar visual-line-mode nil)
(make-variable-buffer-local 'visual-line-mode)

(defun visual-line-mode (arg)
  "*Sets (with postive numeric ARG), clears (with non-positive numeric ARG),
or toggles (with no ARG) visual line mode, in which lines are wrapped at word
boundaries, and line movement commands work relative to screen lines,
rather than lines in the buffer."
  (interactive "P")
  (let ((v (if (null arg) (not visual-line-mode)
	     (> (prefix-numeric-value arg) 0))))
    (setq visual-line-mode v)
    (if visual-line-mode
	(progn (setq word-wrap t) (setq line-move-visual t))
      (setq word-wrap nil)
      (setq line-move-visual nil))))

(or (assq 'visual-line-mode minor-mode-alist)
    (setq minor-mode-alist
	  (cons '(visual-line-mode " Wrap") minor-mode-alist)))



;;; misc.el ends here
