;; bidi class properties.
;; everything defaults to L at the system level.

;; first set the script defaults
(defun bidi-range (first last &optional class)
  (when (null class)
    (setq class last)
    (setq last first))
  (let ((i first))
    (while (<= i last)
      (set-char-display-property (make-char 'ucs i) 'bidi-class class)
      (setq i (1+ i)))))

(bidi-range #x0600  #x06FF 'bidi-al)
(bidi-range #x0700  #x074F 'bidi-al)
(bidi-range #x0750  #x077F 'bidi-al)
(bidi-range #x0780  #x07BF 'bidi-al)
(bidi-range #x08A0  #x08FF 'bidi-al)
(bidi-range #xFB50  #xFDCF 'bidi-al)
(bidi-range #xFDF0  #xFDFF 'bidi-al)
(bidi-range #xFE70  #xFEFF 'bidi-al)
(bidi-range #x1EE00 #x1EEFF 'bidi-al)

(bidi-range #x0590    #x05FF 'bidi-r)
(bidi-range #x07C0    #x07FF 'bidi-r)
(bidi-range #x10800  #x1083F 'bidi-r)
(bidi-range #x10900  #x1091F 'bidi-r)
(bidi-range #x10920  #x1093F 'bidi-r)
(bidi-range #x10980  #x1099F 'bidi-r)
(bidi-range #x109A0  #x109FF 'bidi-r)
(bidi-range #x10A00  #x10A5F 'bidi-r)
(bidi-range #x0800    #x089F 'bidi-r)
(bidi-range #xFB1D    #xFB4F 'bidi-r)
(bidi-range #x10840  #x10FFF 'bidi-r)
(bidi-range #x1E800  #x1EDFF 'bidi-r)
(bidi-range #x1EF00  #x1EFFF 'bidi-r)

(bidi-range #x20A0 #x20CF 'bidi-et)

;; we'll ignore unassigned code points that default to BN for the moment

;; the following points are class R and not in the ranges above

(bidi-range #x200F #x200F 'bidi-r)
(bidi-range #x10940 #x1097F 'bidi-r)
(bidi-range #x10A60 #x10A7C 'bidi-r)
(bidi-range #x10A7D #x10A7E 'bidi-r)
(bidi-range #x10A7F #x10A7F 'bidi-r)
(bidi-range #x10A80 #x10A9C 'bidi-r)
(bidi-range #x10A9D #x10A9F 'bidi-r)
(bidi-range #x10AA0 #x10ABF 'bidi-r)
(bidi-range #x10AC0 #x10AC7 'bidi-r)
(bidi-range #x10AC8 #x10AC8 'bidi-r)
(bidi-range #x10AC9 #x10AE4 'bidi-r)
(bidi-range #x10AE7 #x10AEA 'bidi-r)
(bidi-range #x10AEB #x10AEF 'bidi-r)
(bidi-range #x10AF0 #x10AF6 'bidi-r)
(bidi-range #x10AF7 #x10AFF 'bidi-r)
(bidi-range #x10B00 #x10B35 'bidi-r)
(bidi-range #x10B36 #x10B38 'bidi-r)
(bidi-range #x10B40 #x10B55 'bidi-r)
(bidi-range #x10B56 #x10B57 'bidi-r)
(bidi-range #x10B58 #x10B5F 'bidi-r)
(bidi-range #x10B60 #x10B72 'bidi-r)
(bidi-range #x10B73 #x10B77 'bidi-r)
(bidi-range #x10B78 #x10B7F 'bidi-r)
(bidi-range #x10B80 #x10B91 'bidi-r)
(bidi-range #x10B92 #x10B98 'bidi-r)
(bidi-range #x10B99 #x10B9C 'bidi-r)
(bidi-range #x10B9D #x10BA8 'bidi-r)
(bidi-range #x10BA9 #x10BAF 'bidi-r)
(bidi-range #x10BB0 #x10BFF 'bidi-r)
(bidi-range #x10C00 #x10C48 'bidi-r)
(bidi-range #x10C49 #x10E5F 'bidi-r)
(bidi-range #x10E7F #x10FFF 'bidi-r)

;; oh sod it, we'll just do them all from now on

(bidi-range #x0030 #x0039    'bidi-en)
(bidi-range #x00B2 #x00B3    'bidi-en)
(bidi-range #x00B9          'bidi-en)
(bidi-range #x06F0 #x06F9    'bidi-en)
(bidi-range #x2070          'bidi-en)
(bidi-range #x2074 #x2079    'bidi-en)
(bidi-range #x2080 #x2089    'bidi-en)
(bidi-range #x2488 #x249B    'bidi-en)
(bidi-range #xFF10 #xFF19    'bidi-en)
(bidi-range #x102E1 #x102FB  'bidi-en)
(bidi-range #x1D7CE #x1D7FF  'bidi-en)
(bidi-range #x1F100 #x1F10A  'bidi-en)
(bidi-range #x002B          'bidi-es)
(bidi-range #x002D          'bidi-es)
(bidi-range #x207A #x207B    'bidi-es)
(bidi-range #x208A #x208B    'bidi-es)
(bidi-range #x2212          'bidi-es)
(bidi-range #xFB29          'bidi-es)
(bidi-range #xFE62          'bidi-es)
(bidi-range #xFE63          'bidi-es)
(bidi-range #xFF0B          'bidi-es)
(bidi-range #xFF0D          'bidi-es)
(bidi-range #x0023          'bidi-et)
(bidi-range #x0024          'bidi-et)
(bidi-range #x0025          'bidi-et)
(bidi-range #x00A2 #x00A5    'bidi-et)
(bidi-range #x00B0          'bidi-et)
(bidi-range #x00B1          'bidi-et)
(bidi-range #x058F          'bidi-et)
(bidi-range #x0609 #x060A    'bidi-et)
(bidi-range #x066A          'bidi-et)
(bidi-range #x09F2 #x09F3    'bidi-et)
(bidi-range #x09FB          'bidi-et)
(bidi-range #x0AF1          'bidi-et)
(bidi-range #x0BF9          'bidi-et)
(bidi-range #x0E3F          'bidi-et)
(bidi-range #x17DB          'bidi-et)
(bidi-range #x2030 #x2034    'bidi-et)
(bidi-range #x20A0 #x20BD    'bidi-et)
(bidi-range #x20BE #x20CF    'bidi-et)
(bidi-range #x212E          'bidi-et)
(bidi-range #x2213          'bidi-et)
(bidi-range #xA838          'bidi-et)
(bidi-range #xA839          'bidi-et)
(bidi-range #xFE5F          'bidi-et)
(bidi-range #xFE69          'bidi-et)
(bidi-range #xFE6A          'bidi-et)
(bidi-range #xFF03          'bidi-et)
(bidi-range #xFF04          'bidi-et)
(bidi-range #xFF05          'bidi-et)
(bidi-range #xFFE0 #xFFE1    'bidi-et)
(bidi-range #xFFE5 #xFFE6    'bidi-et)
(bidi-range #x0600 #x0605    'bidi-an)
(bidi-range #x0660 #x0669    'bidi-an)
(bidi-range #x066B #x066C    'bidi-an)
(bidi-range #x06DD          'bidi-an)
(bidi-range #x10E60 #x10E7E  'bidi-an)
(bidi-range #x002C          'bidi-cs)
(bidi-range #x002E #x002F    'bidi-cs)
(bidi-range #x003A          'bidi-cs)
(bidi-range #x00A0          'bidi-cs)
(bidi-range #x060C          'bidi-cs)
(bidi-range #x202F          'bidi-cs)
(bidi-range #x2044          'bidi-cs)
(bidi-range #xFE50          'bidi-cs)
(bidi-range #xFE52          'bidi-cs)
(bidi-range #xFE55          'bidi-cs)
(bidi-range #xFF0C          'bidi-cs)
(bidi-range #xFF0E #xFF0F    'bidi-cs)
(bidi-range #xFF1A          'bidi-cs)
(bidi-range #x000A          'bidi-b)
(bidi-range #x000D          'bidi-b)
(bidi-range #x001C #x001E    'bidi-b)
(bidi-range #x0085          'bidi-b)
(bidi-range #x2029          'bidi-b)
(bidi-range #x0009          'bidi-s)
(bidi-range #x000B          'bidi-s)
(bidi-range #x001F          'bidi-s)
(bidi-range #x000C          'bidi-ws)
(bidi-range #x0020          'bidi-ws)
(bidi-range #x1680          'bidi-ws)
(bidi-range #x2000 #x200A    'bidi-ws)
(bidi-range #x2028          'bidi-ws)
(bidi-range #x205F          'bidi-ws)
(bidi-range #x3000          'bidi-ws)
(bidi-range #x0021 #x0022    'bidi-on)
(bidi-range #x0026 #x0027    'bidi-on)
(bidi-range #x0028          'bidi-on)
(bidi-range #x0029          'bidi-on)
(bidi-range #x002A          'bidi-on)
(bidi-range #x003B          'bidi-on)
(bidi-range #x003C #x003E    'bidi-on)
(bidi-range #x003F #x0040    'bidi-on)
(bidi-range #x005B          'bidi-on)
(bidi-range #x005C          'bidi-on)
(bidi-range #x005D          'bidi-on)
(bidi-range #x005E          'bidi-on)
(bidi-range #x005F          'bidi-on)
(bidi-range #x0060          'bidi-on)
(bidi-range #x007B          'bidi-on)
(bidi-range #x007C          'bidi-on)
(bidi-range #x007D          'bidi-on)
(bidi-range #x007E          'bidi-on)
(bidi-range #x00A1          'bidi-on)
(bidi-range #x00A6          'bidi-on)
(bidi-range #x00A7          'bidi-on)
(bidi-range #x00A8          'bidi-on)
(bidi-range #x00A9          'bidi-on)
(bidi-range #x00AB          'bidi-on)
(bidi-range #x00AC          'bidi-on)
(bidi-range #x00AE          'bidi-on)
(bidi-range #x00AF          'bidi-on)
(bidi-range #x00B4          'bidi-on)
(bidi-range #x00B6 #x00B7    'bidi-on)
(bidi-range #x00B8          'bidi-on)
(bidi-range #x00BB          'bidi-on)
(bidi-range #x00BC #x00BE    'bidi-on)
(bidi-range #x00BF          'bidi-on)
(bidi-range #x00D7          'bidi-on)
(bidi-range #x00F7          'bidi-on)
(bidi-range #x02B9 #x02BA    'bidi-on)
(bidi-range #x02C2 #x02C5    'bidi-on)
(bidi-range #x02C6 #x02CF    'bidi-on)
(bidi-range #x02D2 #x02DF    'bidi-on)
(bidi-range #x02E5 #x02EB    'bidi-on)
(bidi-range #x02EC          'bidi-on)
(bidi-range #x02ED          'bidi-on)
(bidi-range #x02EF #x02FF    'bidi-on)
(bidi-range #x0374          'bidi-on)
(bidi-range #x0375          'bidi-on)
(bidi-range #x037E          'bidi-on)
(bidi-range #x0384 #x0385    'bidi-on)
(bidi-range #x0387          'bidi-on)
(bidi-range #x03F6          'bidi-on)
(bidi-range #x058A          'bidi-on)
(bidi-range #x058D #x058E    'bidi-on)
(bidi-range #x0606 #x0607    'bidi-on)
(bidi-range #x060E #x060F    'bidi-on)
(bidi-range #x06DE          'bidi-on)
(bidi-range #x06E9          'bidi-on)
(bidi-range #x07F6          'bidi-on)
(bidi-range #x07F7 #x07F9    'bidi-on)
(bidi-range #x0BF3 #x0BF8    'bidi-on)
(bidi-range #x0BFA          'bidi-on)
(bidi-range #x0C78 #x0C7E    'bidi-on)
(bidi-range #x0F3A          'bidi-on)
(bidi-range #x0F3B          'bidi-on)
(bidi-range #x0F3C          'bidi-on)
(bidi-range #x0F3D          'bidi-on)
(bidi-range #x1390 #x1399    'bidi-on)
(bidi-range #x1400          'bidi-on)
(bidi-range #x169B          'bidi-on)
(bidi-range #x169C          'bidi-on)
(bidi-range #x17F0 #x17F9    'bidi-on)
(bidi-range #x1800 #x1805    'bidi-on)
(bidi-range #x1806          'bidi-on)
(bidi-range #x1807 #x180A    'bidi-on)
(bidi-range #x1940          'bidi-on)
(bidi-range #x1944 #x1945    'bidi-on)
(bidi-range #x19DE #x19FF    'bidi-on)
(bidi-range #x1FBD          'bidi-on)
(bidi-range #x1FBF #x1FC1    'bidi-on)
(bidi-range #x1FCD #x1FCF    'bidi-on)
(bidi-range #x1FDD #x1FDF    'bidi-on)
(bidi-range #x1FED #x1FEF    'bidi-on)
(bidi-range #x1FFD #x1FFE    'bidi-on)
(bidi-range #x2010 #x2015    'bidi-on)
(bidi-range #x2016 #x2017    'bidi-on)
(bidi-range #x2018          'bidi-on)
(bidi-range #x2019          'bidi-on)
(bidi-range #x201A          'bidi-on)
(bidi-range #x201B #x201C    'bidi-on)
(bidi-range #x201D          'bidi-on)
(bidi-range #x201E          'bidi-on)
(bidi-range #x201F          'bidi-on)
(bidi-range #x2020 #x2027    'bidi-on)
(bidi-range #x2035 #x2038    'bidi-on)
(bidi-range #x2039          'bidi-on)
(bidi-range #x203A          'bidi-on)
(bidi-range #x203B #x203E    'bidi-on)
(bidi-range #x203F #x2040    'bidi-on)
(bidi-range #x2041 #x2043    'bidi-on)
(bidi-range #x2045          'bidi-on)
(bidi-range #x2046          'bidi-on)
(bidi-range #x2047 #x2051    'bidi-on)
(bidi-range #x2052          'bidi-on)
(bidi-range #x2053          'bidi-on)
(bidi-range #x2054          'bidi-on)
(bidi-range #x2055 #x205E    'bidi-on)
(bidi-range #x207C          'bidi-on)
(bidi-range #x207D          'bidi-on)
(bidi-range #x207E          'bidi-on)
(bidi-range #x208C          'bidi-on)
(bidi-range #x208D          'bidi-on)
(bidi-range #x208E          'bidi-on)
(bidi-range #x2100 #x2101    'bidi-on)
(bidi-range #x2103 #x2106    'bidi-on)
(bidi-range #x2108 #x2109    'bidi-on)
(bidi-range #x2114          'bidi-on)
(bidi-range #x2116 #x2117    'bidi-on)
(bidi-range #x2118          'bidi-on)
(bidi-range #x211E #x2123    'bidi-on)
(bidi-range #x2125          'bidi-on)
(bidi-range #x2127          'bidi-on)
(bidi-range #x2129          'bidi-on)
(bidi-range #x213A #x213B    'bidi-on)
(bidi-range #x2140 #x2144    'bidi-on)
(bidi-range #x214A          'bidi-on)
(bidi-range #x214B          'bidi-on)
(bidi-range #x214C #x214D    'bidi-on)
(bidi-range #x2150 #x215F    'bidi-on)
(bidi-range #x2189          'bidi-on)
(bidi-range #x2190 #x2194    'bidi-on)
(bidi-range #x2195 #x2199    'bidi-on)
(bidi-range #x219A #x219B    'bidi-on)
(bidi-range #x219C #x219F    'bidi-on)
(bidi-range #x21A0          'bidi-on)
(bidi-range #x21A1 #x21A2    'bidi-on)
(bidi-range #x21A3          'bidi-on)
(bidi-range #x21A4 #x21A5    'bidi-on)
(bidi-range #x21A6          'bidi-on)
(bidi-range #x21A7 #x21AD    'bidi-on)
(bidi-range #x21AE          'bidi-on)
(bidi-range #x21AF #x21CD    'bidi-on)
(bidi-range #x21CE #x21CF    'bidi-on)
(bidi-range #x21D0 #x21D1    'bidi-on)
(bidi-range #x21D2          'bidi-on)
(bidi-range #x21D3          'bidi-on)
(bidi-range #x21D4          'bidi-on)
(bidi-range #x21D5 #x21F3    'bidi-on)
(bidi-range #x21F4 #x2211    'bidi-on)
(bidi-range #x2214 #x22FF    'bidi-on)
(bidi-range #x2300 #x2307    'bidi-on)
(bidi-range #x2308          'bidi-on)
(bidi-range #x2309          'bidi-on)
(bidi-range #x230A          'bidi-on)
(bidi-range #x230B          'bidi-on)
(bidi-range #x230C #x231F    'bidi-on)
(bidi-range #x2320 #x2321    'bidi-on)
(bidi-range #x2322 #x2328    'bidi-on)
(bidi-range #x2329          'bidi-on)
(bidi-range #x232A          'bidi-on)
(bidi-range #x232B #x2335    'bidi-on)
(bidi-range #x237B          'bidi-on)
(bidi-range #x237C          'bidi-on)
(bidi-range #x237D #x2394    'bidi-on)
(bidi-range #x2396 #x239A    'bidi-on)
(bidi-range #x239B #x23B3    'bidi-on)
(bidi-range #x23B4 #x23DB    'bidi-on)
(bidi-range #x23DC #x23E1    'bidi-on)
(bidi-range #x23E2 #x23FA    'bidi-on)
(bidi-range #x2400 #x2426    'bidi-on)
(bidi-range #x2440 #x244A    'bidi-on)
(bidi-range #x2460 #x2487    'bidi-on)
(bidi-range #x24EA #x24FF    'bidi-on)
(bidi-range #x2500 #x25B6    'bidi-on)
(bidi-range #x25B7          'bidi-on)
(bidi-range #x25B8 #x25C0    'bidi-on)
(bidi-range #x25C1          'bidi-on)
(bidi-range #x25C2 #x25F7    'bidi-on)
(bidi-range #x25F8 #x25FF    'bidi-on)
(bidi-range #x2600 #x266E    'bidi-on)
(bidi-range #x266F          'bidi-on)
(bidi-range #x2670 #x26AB    'bidi-on)
(bidi-range #x26AD #x2767    'bidi-on)
(bidi-range #x2768          'bidi-on)
(bidi-range #x2769          'bidi-on)
(bidi-range #x276A          'bidi-on)
(bidi-range #x276B          'bidi-on)
(bidi-range #x276C          'bidi-on)
(bidi-range #x276D          'bidi-on)
(bidi-range #x276E          'bidi-on)
(bidi-range #x276F          'bidi-on)
(bidi-range #x2770          'bidi-on)
(bidi-range #x2771          'bidi-on)
(bidi-range #x2772          'bidi-on)
(bidi-range #x2773          'bidi-on)
(bidi-range #x2774          'bidi-on)
(bidi-range #x2775          'bidi-on)
(bidi-range #x2776 #x2793    'bidi-on)
(bidi-range #x2794 #x27BF    'bidi-on)
(bidi-range #x27C0 #x27C4    'bidi-on)
(bidi-range #x27C5          'bidi-on)
(bidi-range #x27C6          'bidi-on)
(bidi-range #x27C7 #x27E5    'bidi-on)
(bidi-range #x27E6          'bidi-on)
(bidi-range #x27E7          'bidi-on)
(bidi-range #x27E8          'bidi-on)
(bidi-range #x27E9          'bidi-on)
(bidi-range #x27EA          'bidi-on)
(bidi-range #x27EB          'bidi-on)
(bidi-range #x27EC          'bidi-on)
(bidi-range #x27ED          'bidi-on)
(bidi-range #x27EE          'bidi-on)
(bidi-range #x27EF          'bidi-on)
(bidi-range #x27F0 #x27FF    'bidi-on)
(bidi-range #x2900 #x2982    'bidi-on)
(bidi-range #x2983          'bidi-on)
(bidi-range #x2984          'bidi-on)
(bidi-range #x2985          'bidi-on)
(bidi-range #x2986          'bidi-on)
(bidi-range #x2987          'bidi-on)
(bidi-range #x2988          'bidi-on)
(bidi-range #x2989          'bidi-on)
(bidi-range #x298A          'bidi-on)
(bidi-range #x298B          'bidi-on)
(bidi-range #x298C          'bidi-on)
(bidi-range #x298D          'bidi-on)
(bidi-range #x298E          'bidi-on)
(bidi-range #x298F          'bidi-on)
(bidi-range #x2990          'bidi-on)
(bidi-range #x2991          'bidi-on)
(bidi-range #x2992          'bidi-on)
(bidi-range #x2993          'bidi-on)
(bidi-range #x2994          'bidi-on)
(bidi-range #x2995          'bidi-on)
(bidi-range #x2996          'bidi-on)
(bidi-range #x2997          'bidi-on)
(bidi-range #x2998          'bidi-on)
(bidi-range #x2999 #x29D7    'bidi-on)
(bidi-range #x29D8          'bidi-on)
(bidi-range #x29D9          'bidi-on)
(bidi-range #x29DA          'bidi-on)
(bidi-range #x29DB          'bidi-on)
(bidi-range #x29DC #x29FB    'bidi-on)
(bidi-range #x29FC          'bidi-on)
(bidi-range #x29FD          'bidi-on)
(bidi-range #x29FE #x2AFF    'bidi-on)
(bidi-range #x2B00 #x2B2F    'bidi-on)
(bidi-range #x2B30 #x2B44    'bidi-on)
(bidi-range #x2B45 #x2B46    'bidi-on)
(bidi-range #x2B47 #x2B4C    'bidi-on)
(bidi-range #x2B4D #x2B73    'bidi-on)
(bidi-range #x2B76 #x2B95    'bidi-on)
(bidi-range #x2B98 #x2BB9    'bidi-on)
(bidi-range #x2BBD #x2BC8    'bidi-on)
(bidi-range #x2BCA #x2BD1    'bidi-on)
(bidi-range #x2CE5 #x2CEA    'bidi-on)
(bidi-range #x2CF9 #x2CFC    'bidi-on)
(bidi-range #x2CFD          'bidi-on)
(bidi-range #x2CFE #x2CFF    'bidi-on)
(bidi-range #x2E00 #x2E01    'bidi-on)
(bidi-range #x2E02          'bidi-on)
(bidi-range #x2E03          'bidi-on)
(bidi-range #x2E04          'bidi-on)
(bidi-range #x2E05          'bidi-on)
(bidi-range #x2E06 #x2E08    'bidi-on)
(bidi-range #x2E09          'bidi-on)
(bidi-range #x2E0A          'bidi-on)
(bidi-range #x2E0B          'bidi-on)
(bidi-range #x2E0C          'bidi-on)
(bidi-range #x2E0D          'bidi-on)
(bidi-range #x2E0E #x2E16    'bidi-on)
(bidi-range #x2E17          'bidi-on)
(bidi-range #x2E18 #x2E19    'bidi-on)
(bidi-range #x2E1A          'bidi-on)
(bidi-range #x2E1B          'bidi-on)
(bidi-range #x2E1C          'bidi-on)
(bidi-range #x2E1D          'bidi-on)
(bidi-range #x2E1E #x2E1F    'bidi-on)
(bidi-range #x2E20          'bidi-on)
(bidi-range #x2E21          'bidi-on)
(bidi-range #x2E22          'bidi-on)
(bidi-range #x2E23          'bidi-on)
(bidi-range #x2E24          'bidi-on)
(bidi-range #x2E25          'bidi-on)
(bidi-range #x2E26          'bidi-on)
(bidi-range #x2E27          'bidi-on)
(bidi-range #x2E28          'bidi-on)
(bidi-range #x2E29          'bidi-on)
(bidi-range #x2E2A #x2E2E    'bidi-on)
(bidi-range #x2E2F          'bidi-on)
(bidi-range #x2E30 #x2E39    'bidi-on)
(bidi-range #x2E3A #x2E3B    'bidi-on)
(bidi-range #x2E3C #x2E3F    'bidi-on)
(bidi-range #x2E40          'bidi-on)
(bidi-range #x2E41          'bidi-on)
(bidi-range #x2E42          'bidi-on)
(bidi-range #x2E80 #x2E99    'bidi-on)
(bidi-range #x2E9B #x2EF3    'bidi-on)
(bidi-range #x2F00 #x2FD5    'bidi-on)
(bidi-range #x2FF0 #x2FFB    'bidi-on)
(bidi-range #x3001 #x3003    'bidi-on)
(bidi-range #x3004          'bidi-on)
(bidi-range #x3008          'bidi-on)
(bidi-range #x3009          'bidi-on)
(bidi-range #x300A          'bidi-on)
(bidi-range #x300B          'bidi-on)
(bidi-range #x300C          'bidi-on)
(bidi-range #x300D          'bidi-on)
(bidi-range #x300E          'bidi-on)
(bidi-range #x300F          'bidi-on)
(bidi-range #x3010          'bidi-on)
(bidi-range #x3011          'bidi-on)
(bidi-range #x3012 #x3013    'bidi-on)
(bidi-range #x3014          'bidi-on)
(bidi-range #x3015          'bidi-on)
(bidi-range #x3016          'bidi-on)
(bidi-range #x3017          'bidi-on)
(bidi-range #x3018          'bidi-on)
(bidi-range #x3019          'bidi-on)
(bidi-range #x301A          'bidi-on)
(bidi-range #x301B          'bidi-on)
(bidi-range #x301C          'bidi-on)
(bidi-range #x301D          'bidi-on)
(bidi-range #x301E #x301F    'bidi-on)
(bidi-range #x3020          'bidi-on)
(bidi-range #x3030          'bidi-on)
(bidi-range #x3036 #x3037    'bidi-on)
(bidi-range #x303D          'bidi-on)
(bidi-range #x303E #x303F    'bidi-on)
(bidi-range #x309B #x309C    'bidi-on)
(bidi-range #x30A0          'bidi-on)
(bidi-range #x30FB          'bidi-on)
(bidi-range #x31C0 #x31E3    'bidi-on)
(bidi-range #x321D #x321E    'bidi-on)
(bidi-range #x3250          'bidi-on)
(bidi-range #x3251 #x325F    'bidi-on)
(bidi-range #x327C #x327E    'bidi-on)
(bidi-range #x32B1 #x32BF    'bidi-on)
(bidi-range #x32CC #x32CF    'bidi-on)
(bidi-range #x3377 #x337A    'bidi-on)
(bidi-range #x33DE #x33DF    'bidi-on)
(bidi-range #x33FF          'bidi-on)
(bidi-range #x4DC0 #x4DFF    'bidi-on)
(bidi-range #xA490 #xA4C6    'bidi-on)
(bidi-range #xA60D #xA60F    'bidi-on)
(bidi-range #xA673          'bidi-on)
(bidi-range #xA67E          'bidi-on)
(bidi-range #xA67F          'bidi-on)
(bidi-range #xA700 #xA716    'bidi-on)
(bidi-range #xA717 #xA71F    'bidi-on)
(bidi-range #xA720 #xA721    'bidi-on)
(bidi-range #xA788          'bidi-on)
(bidi-range #xA828 #xA82B    'bidi-on)
(bidi-range #xA874 #xA877    'bidi-on)
(bidi-range #xFD3E          'bidi-on)
(bidi-range #xFD3F          'bidi-on)
(bidi-range #xFDFD          'bidi-on)
(bidi-range #xFE10 #xFE16    'bidi-on)
(bidi-range #xFE17          'bidi-on)
(bidi-range #xFE18          'bidi-on)
(bidi-range #xFE19          'bidi-on)
(bidi-range #xFE30          'bidi-on)
(bidi-range #xFE31 #xFE32    'bidi-on)
(bidi-range #xFE33 #xFE34    'bidi-on)
(bidi-range #xFE35          'bidi-on)
(bidi-range #xFE36          'bidi-on)
(bidi-range #xFE37          'bidi-on)
(bidi-range #xFE38          'bidi-on)
(bidi-range #xFE39          'bidi-on)
(bidi-range #xFE3A          'bidi-on)
(bidi-range #xFE3B          'bidi-on)
(bidi-range #xFE3C          'bidi-on)
(bidi-range #xFE3D          'bidi-on)
(bidi-range #xFE3E          'bidi-on)
(bidi-range #xFE3F          'bidi-on)
(bidi-range #xFE40          'bidi-on)
(bidi-range #xFE41          'bidi-on)
(bidi-range #xFE42          'bidi-on)
(bidi-range #xFE43          'bidi-on)
(bidi-range #xFE44          'bidi-on)
(bidi-range #xFE45 #xFE46    'bidi-on)
(bidi-range #xFE47          'bidi-on)
(bidi-range #xFE48          'bidi-on)
(bidi-range #xFE49 #xFE4C    'bidi-on)
(bidi-range #xFE4D #xFE4F    'bidi-on)
(bidi-range #xFE51          'bidi-on)
(bidi-range #xFE54          'bidi-on)
(bidi-range #xFE56 #xFE57    'bidi-on)
(bidi-range #xFE58          'bidi-on)
(bidi-range #xFE59          'bidi-on)
(bidi-range #xFE5A          'bidi-on)
(bidi-range #xFE5B          'bidi-on)
(bidi-range #xFE5C          'bidi-on)
(bidi-range #xFE5D          'bidi-on)
(bidi-range #xFE5E          'bidi-on)
(bidi-range #xFE60 #xFE61    'bidi-on)
(bidi-range #xFE64 #xFE66    'bidi-on)
(bidi-range #xFE68          'bidi-on)
(bidi-range #xFE6B          'bidi-on)
(bidi-range #xFF01 #xFF02    'bidi-on)
(bidi-range #xFF06 #xFF07    'bidi-on)
(bidi-range #xFF08          'bidi-on)
(bidi-range #xFF09          'bidi-on)
(bidi-range #xFF0A          'bidi-on)
(bidi-range #xFF1B          'bidi-on)
(bidi-range #xFF1C #xFF1E    'bidi-on)
(bidi-range #xFF1F #xFF20    'bidi-on)
(bidi-range #xFF3B          'bidi-on)
(bidi-range #xFF3C          'bidi-on)
(bidi-range #xFF3D          'bidi-on)
(bidi-range #xFF3E          'bidi-on)
(bidi-range #xFF3F          'bidi-on)
(bidi-range #xFF40          'bidi-on)
(bidi-range #xFF5B          'bidi-on)
(bidi-range #xFF5C          'bidi-on)
(bidi-range #xFF5D          'bidi-on)
(bidi-range #xFF5E          'bidi-on)
(bidi-range #xFF5F          'bidi-on)
(bidi-range #xFF60          'bidi-on)
(bidi-range #xFF61          'bidi-on)
(bidi-range #xFF62          'bidi-on)
(bidi-range #xFF63          'bidi-on)
(bidi-range #xFF64 #xFF65    'bidi-on)
(bidi-range #xFFE2          'bidi-on)
(bidi-range #xFFE3          'bidi-on)
(bidi-range #xFFE4          'bidi-on)
(bidi-range #xFFE8          'bidi-on)
(bidi-range #xFFE9 #xFFEC    'bidi-on)
(bidi-range #xFFED #xFFEE    'bidi-on)
(bidi-range #xFFF9 #xFFFB    'bidi-on)
(bidi-range #xFFFC #xFFFD    'bidi-on)
(bidi-range #x10101         'bidi-on)
(bidi-range #x10140 #x10174  'bidi-on)
(bidi-range #x10175 #x10178  'bidi-on)
(bidi-range #x10179 #x10189  'bidi-on)
(bidi-range #x1018A #x1018B  'bidi-on)
(bidi-range #x1018C         'bidi-on)
(bidi-range #x10190 #x1019B  'bidi-on)
(bidi-range #x101A0         'bidi-on)
(bidi-range #x1091F         'bidi-on)
(bidi-range #x10B39 #x10B3F  'bidi-on)
(bidi-range #x11052 #x11065  'bidi-on)
(bidi-range #x1D200 #x1D241  'bidi-on)
(bidi-range #x1D245         'bidi-on)
(bidi-range #x1D300 #x1D356  'bidi-on)
(bidi-range #x1D6DB         'bidi-on)
(bidi-range #x1D715         'bidi-on)
(bidi-range #x1D74F         'bidi-on)
(bidi-range #x1D789         'bidi-on)
(bidi-range #x1D7C3         'bidi-on)
(bidi-range #x1EEF0 #x1EEF1  'bidi-on)
(bidi-range #x1F000 #x1F02B  'bidi-on)
(bidi-range #x1F030 #x1F093  'bidi-on)
(bidi-range #x1F0A0 #x1F0AE  'bidi-on)
(bidi-range #x1F0B1 #x1F0BF  'bidi-on)
(bidi-range #x1F0C1 #x1F0CF  'bidi-on)
(bidi-range #x1F0D1 #x1F0F5  'bidi-on)
(bidi-range #x1F10B #x1F10C  'bidi-on)
(bidi-range #x1F16A #x1F16B  'bidi-on)
(bidi-range #x1F300 #x1F32C  'bidi-on)
(bidi-range #x1F330 #x1F37D  'bidi-on)
(bidi-range #x1F380 #x1F3CE  'bidi-on)
(bidi-range #x1F3D4 #x1F3F7  'bidi-on)
(bidi-range #x1F400 #x1F4FE  'bidi-on)
(bidi-range #x1F500 #x1F54A  'bidi-on)
(bidi-range #x1F550 #x1F579  'bidi-on)
(bidi-range #x1F57B #x1F5A3  'bidi-on)
(bidi-range #x1F5A5 #x1F642  'bidi-on)
(bidi-range #x1F645 #x1F6CF  'bidi-on)
(bidi-range #x1F6E0 #x1F6EC  'bidi-on)
(bidi-range #x1F6F0 #x1F6F3  'bidi-on)
(bidi-range #x1F700 #x1F773  'bidi-on)
(bidi-range #x1F780 #x1F7D4  'bidi-on)
(bidi-range #x1F800 #x1F80B  'bidi-on)
(bidi-range #x1F810 #x1F847  'bidi-on)
(bidi-range #x1F850 #x1F859  'bidi-on)
(bidi-range #x1F860 #x1F887  'bidi-on)
(bidi-range #x1F890 #x1F8AD  'bidi-on)
(bidi-range #x0000 #x0008    'bidi-bn)
(bidi-range #x000E #x001B    'bidi-bn)
(bidi-range #x007F #x0084    'bidi-bn)
(bidi-range #x0086 #x009F    'bidi-bn)
(bidi-range #x00AD          'bidi-bn)
(bidi-range #x180E          'bidi-bn)
(bidi-range #x200B #x200D    'bidi-bn)
(bidi-range #x2060 #x2064    'bidi-bn)
(bidi-range #x2065          'bidi-bn)
(bidi-range #x206A #x206F    'bidi-bn)
(bidi-range #xFDD0 #xFDEF    'bidi-bn)
(bidi-range #xFEFF          'bidi-bn)
(bidi-range #xFFF0 #xFFF8    'bidi-bn)
(bidi-range #xFFFE #xFFFF    'bidi-bn)
(bidi-range #x1BCA0 #x1BCA3  'bidi-bn)
(bidi-range #x1D173 #x1D17A  'bidi-bn)
(bidi-range #x1FFFE #x1FFFF  'bidi-bn)
(bidi-range #x2FFFE #x2FFFF  'bidi-bn)
(bidi-range #x3FFFE #x3FFFF  'bidi-bn)
(bidi-range #x4FFFE #x4FFFF  'bidi-bn)
(bidi-range #x5FFFE #x5FFFF  'bidi-bn)
(bidi-range #x6FFFE #x6FFFF  'bidi-bn)
(bidi-range #x7FFFE #x7FFFF  'bidi-bn)
(bidi-range #x8FFFE #x8FFFF  'bidi-bn)
(bidi-range #x9FFFE #x9FFFF  'bidi-bn)
(bidi-range #xAFFFE #xAFFFF  'bidi-bn)
(bidi-range #xBFFFE #xBFFFF  'bidi-bn)
(bidi-range #xCFFFE #xCFFFF  'bidi-bn)
(bidi-range #xDFFFE #xE0000  'bidi-bn)
(bidi-range #xE0001         'bidi-bn)
(bidi-range #xE0002 #xE001F  'bidi-bn)
(bidi-range #xE0020 #xE007F  'bidi-bn)
(bidi-range #xE0080 #xE00FF  'bidi-bn)
(bidi-range #xE01F0 #xE0FFF  'bidi-bn)
(bidi-range #xEFFFE #xEFFFF  'bidi-bn)
(bidi-range #xFFFFE #xFFFFF  'bidi-bn)
(bidi-range #x10FFFE #x10FFFF'bidi-bn)
(bidi-range #x0300 #x036F    'bidi-nsm)
(bidi-range #x0483 #x0487    'bidi-nsm)
(bidi-range #x0488 #x0489    'bidi-nsm)
(bidi-range #x0591 #x05BD    'bidi-nsm)
(bidi-range #x05BF          'bidi-nsm)
(bidi-range #x05C1 #x05C2    'bidi-nsm)
(bidi-range #x05C4 #x05C5    'bidi-nsm)
(bidi-range #x05C7          'bidi-nsm)
(bidi-range #x0610 #x061A    'bidi-nsm)
(bidi-range #x064B #x065F    'bidi-nsm)
(bidi-range #x0670          'bidi-nsm)
(bidi-range #x06D6 #x06DC    'bidi-nsm)
(bidi-range #x06DF #x06E4    'bidi-nsm)
(bidi-range #x06E7 #x06E8    'bidi-nsm)
(bidi-range #x06EA #x06ED    'bidi-nsm)
(bidi-range #x0711          'bidi-nsm)
(bidi-range #x0730 #x074A    'bidi-nsm)
(bidi-range #x07A6 #x07B0    'bidi-nsm)
(bidi-range #x07EB #x07F3    'bidi-nsm)
(bidi-range #x0816 #x0819    'bidi-nsm)
(bidi-range #x081B #x0823    'bidi-nsm)
(bidi-range #x0825 #x0827    'bidi-nsm)
(bidi-range #x0829 #x082D    'bidi-nsm)
(bidi-range #x0859 #x085B    'bidi-nsm)
(bidi-range #x08E4 #x0902    'bidi-nsm)
(bidi-range #x093A          'bidi-nsm)
(bidi-range #x093C          'bidi-nsm)
(bidi-range #x0941 #x0948    'bidi-nsm)
(bidi-range #x094D          'bidi-nsm)
(bidi-range #x0951 #x0957    'bidi-nsm)
(bidi-range #x0962 #x0963    'bidi-nsm)
(bidi-range #x0981          'bidi-nsm)
(bidi-range #x09BC          'bidi-nsm)
(bidi-range #x09C1 #x09C4    'bidi-nsm)
(bidi-range #x09CD          'bidi-nsm)
(bidi-range #x09E2 #x09E3    'bidi-nsm)
(bidi-range #x0A01 #x0A02    'bidi-nsm)
(bidi-range #x0A3C          'bidi-nsm)
(bidi-range #x0A41 #x0A42    'bidi-nsm)
(bidi-range #x0A47 #x0A48    'bidi-nsm)
(bidi-range #x0A4B #x0A4D    'bidi-nsm)
(bidi-range #x0A51          'bidi-nsm)
(bidi-range #x0A70 #x0A71    'bidi-nsm)
(bidi-range #x0A75          'bidi-nsm)
(bidi-range #x0A81 #x0A82    'bidi-nsm)
(bidi-range #x0ABC          'bidi-nsm)
(bidi-range #x0AC1 #x0AC5    'bidi-nsm)
(bidi-range #x0AC7 #x0AC8    'bidi-nsm)
(bidi-range #x0ACD          'bidi-nsm)
(bidi-range #x0AE2 #x0AE3    'bidi-nsm)
(bidi-range #x0B01          'bidi-nsm)
(bidi-range #x0B3C          'bidi-nsm)
(bidi-range #x0B3F          'bidi-nsm)
(bidi-range #x0B41 #x0B44    'bidi-nsm)
(bidi-range #x0B4D          'bidi-nsm)
(bidi-range #x0B56          'bidi-nsm)
(bidi-range #x0B62 #x0B63    'bidi-nsm)
(bidi-range #x0B82          'bidi-nsm)
(bidi-range #x0BC0          'bidi-nsm)
(bidi-range #x0BCD          'bidi-nsm)
(bidi-range #x0C00          'bidi-nsm)
(bidi-range #x0C3E #x0C40    'bidi-nsm)
(bidi-range #x0C46 #x0C48    'bidi-nsm)
(bidi-range #x0C4A #x0C4D    'bidi-nsm)
(bidi-range #x0C55 #x0C56    'bidi-nsm)
(bidi-range #x0C62 #x0C63    'bidi-nsm)
(bidi-range #x0C81          'bidi-nsm)
(bidi-range #x0CBC          'bidi-nsm)
(bidi-range #x0CCC #x0CCD    'bidi-nsm)
(bidi-range #x0CE2 #x0CE3    'bidi-nsm)
(bidi-range #x0D01          'bidi-nsm)
(bidi-range #x0D41 #x0D44    'bidi-nsm)
(bidi-range #x0D4D          'bidi-nsm)
(bidi-range #x0D62 #x0D63    'bidi-nsm)
(bidi-range #x0DCA          'bidi-nsm)
(bidi-range #x0DD2 #x0DD4    'bidi-nsm)
(bidi-range #x0DD6          'bidi-nsm)
(bidi-range #x0E31          'bidi-nsm)
(bidi-range #x0E34 #x0E3A    'bidi-nsm)
(bidi-range #x0E47 #x0E4E    'bidi-nsm)
(bidi-range #x0EB1          'bidi-nsm)
(bidi-range #x0EB4 #x0EB9    'bidi-nsm)
(bidi-range #x0EBB #x0EBC    'bidi-nsm)
(bidi-range #x0EC8 #x0ECD    'bidi-nsm)
(bidi-range #x0F18 #x0F19    'bidi-nsm)
(bidi-range #x0F35          'bidi-nsm)
(bidi-range #x0F37          'bidi-nsm)
(bidi-range #x0F39          'bidi-nsm)
(bidi-range #x0F71 #x0F7E    'bidi-nsm)
(bidi-range #x0F80 #x0F84    'bidi-nsm)
(bidi-range #x0F86 #x0F87    'bidi-nsm)
(bidi-range #x0F8D #x0F97    'bidi-nsm)
(bidi-range #x0F99 #x0FBC    'bidi-nsm)
(bidi-range #x0FC6          'bidi-nsm)
(bidi-range #x102D #x1030    'bidi-nsm)
(bidi-range #x1032 #x1037    'bidi-nsm)
(bidi-range #x1039 #x103A    'bidi-nsm)
(bidi-range #x103D #x103E    'bidi-nsm)
(bidi-range #x1058 #x1059    'bidi-nsm)
(bidi-range #x105E #x1060    'bidi-nsm)
(bidi-range #x1071 #x1074    'bidi-nsm)
(bidi-range #x1082          'bidi-nsm)
(bidi-range #x1085 #x1086    'bidi-nsm)
(bidi-range #x108D          'bidi-nsm)
(bidi-range #x109D          'bidi-nsm)
(bidi-range #x135D #x135F    'bidi-nsm)
(bidi-range #x1712 #x1714    'bidi-nsm)
(bidi-range #x1732 #x1734    'bidi-nsm)
(bidi-range #x1752 #x1753    'bidi-nsm)
(bidi-range #x1772 #x1773    'bidi-nsm)
(bidi-range #x17B4 #x17B5    'bidi-nsm)
(bidi-range #x17B7 #x17BD    'bidi-nsm)
(bidi-range #x17C6          'bidi-nsm)
(bidi-range #x17C9 #x17D3    'bidi-nsm)
(bidi-range #x17DD          'bidi-nsm)
(bidi-range #x180B #x180D    'bidi-nsm)
(bidi-range #x18A9          'bidi-nsm)
(bidi-range #x1920 #x1922    'bidi-nsm)
(bidi-range #x1927 #x1928    'bidi-nsm)
(bidi-range #x1932          'bidi-nsm)
(bidi-range #x1939 #x193B    'bidi-nsm)
(bidi-range #x1A17 #x1A18    'bidi-nsm)
(bidi-range #x1A1B          'bidi-nsm)
(bidi-range #x1A56          'bidi-nsm)
(bidi-range #x1A58 #x1A5E    'bidi-nsm)
(bidi-range #x1A60          'bidi-nsm)
(bidi-range #x1A62          'bidi-nsm)
(bidi-range #x1A65 #x1A6C    'bidi-nsm)
(bidi-range #x1A73 #x1A7C    'bidi-nsm)
(bidi-range #x1A7F          'bidi-nsm)
(bidi-range #x1AB0 #x1ABD    'bidi-nsm)
(bidi-range #x1ABE          'bidi-nsm)
(bidi-range #x1B00 #x1B03    'bidi-nsm)
(bidi-range #x1B34          'bidi-nsm)
(bidi-range #x1B36 #x1B3A    'bidi-nsm)
(bidi-range #x1B3C          'bidi-nsm)
(bidi-range #x1B42          'bidi-nsm)
(bidi-range #x1B6B #x1B73    'bidi-nsm)
(bidi-range #x1B80 #x1B81    'bidi-nsm)
(bidi-range #x1BA2 #x1BA5    'bidi-nsm)
(bidi-range #x1BA8 #x1BA9    'bidi-nsm)
(bidi-range #x1BAB #x1BAD    'bidi-nsm)
(bidi-range #x1BE6          'bidi-nsm)
(bidi-range #x1BE8 #x1BE9    'bidi-nsm)
(bidi-range #x1BED          'bidi-nsm)
(bidi-range #x1BEF #x1BF1    'bidi-nsm)
(bidi-range #x1C2C #x1C33    'bidi-nsm)
(bidi-range #x1C36 #x1C37    'bidi-nsm)
(bidi-range #x1CD0 #x1CD2    'bidi-nsm)
(bidi-range #x1CD4 #x1CE0    'bidi-nsm)
(bidi-range #x1CE2 #x1CE8    'bidi-nsm)
(bidi-range #x1CED          'bidi-nsm)
(bidi-range #x1CF4          'bidi-nsm)
(bidi-range #x1CF8 #x1CF9    'bidi-nsm)
(bidi-range #x1DC0 #x1DF5    'bidi-nsm)
(bidi-range #x1DFC #x1DFF    'bidi-nsm)
(bidi-range #x20D0 #x20DC    'bidi-nsm)
(bidi-range #x20DD #x20E0    'bidi-nsm)
(bidi-range #x20E1          'bidi-nsm)
(bidi-range #x20E2 #x20E4    'bidi-nsm)
(bidi-range #x20E5 #x20F0    'bidi-nsm)
(bidi-range #x2CEF #x2CF1    'bidi-nsm)
(bidi-range #x2D7F          'bidi-nsm)
(bidi-range #x2DE0 #x2DFF    'bidi-nsm)
(bidi-range #x302A #x302D    'bidi-nsm)
(bidi-range #x3099 #x309A    'bidi-nsm)
(bidi-range #xA66F          'bidi-nsm)
(bidi-range #xA670 #xA672    'bidi-nsm)
(bidi-range #xA674 #xA67D    'bidi-nsm)
(bidi-range #xA69F          'bidi-nsm)
(bidi-range #xA6F0 #xA6F1    'bidi-nsm)
(bidi-range #xA802          'bidi-nsm)
(bidi-range #xA806          'bidi-nsm)
(bidi-range #xA80B          'bidi-nsm)
(bidi-range #xA825 #xA826    'bidi-nsm)
(bidi-range #xA8C4          'bidi-nsm)
(bidi-range #xA8E0 #xA8F1    'bidi-nsm)
(bidi-range #xA926 #xA92D    'bidi-nsm)
(bidi-range #xA947 #xA951    'bidi-nsm)
(bidi-range #xA980 #xA982    'bidi-nsm)
(bidi-range #xA9B3          'bidi-nsm)
(bidi-range #xA9B6 #xA9B9    'bidi-nsm)
(bidi-range #xA9BC          'bidi-nsm)
(bidi-range #xA9E5          'bidi-nsm)
(bidi-range #xAA29 #xAA2E    'bidi-nsm)
(bidi-range #xAA31 #xAA32    'bidi-nsm)
(bidi-range #xAA35 #xAA36    'bidi-nsm)
(bidi-range #xAA43          'bidi-nsm)
(bidi-range #xAA4C          'bidi-nsm)
(bidi-range #xAA7C          'bidi-nsm)
(bidi-range #xAAB0          'bidi-nsm)
(bidi-range #xAAB2 #xAAB4    'bidi-nsm)
(bidi-range #xAAB7 #xAAB8    'bidi-nsm)
(bidi-range #xAABE #xAABF    'bidi-nsm)
(bidi-range #xAAC1          'bidi-nsm)
(bidi-range #xAAEC #xAAED    'bidi-nsm)
(bidi-range #xAAF6          'bidi-nsm)
(bidi-range #xABE5          'bidi-nsm)
(bidi-range #xABE8          'bidi-nsm)
(bidi-range #xABED          'bidi-nsm)
(bidi-range #xFB1E          'bidi-nsm)
(bidi-range #xFE00 #xFE0F    'bidi-nsm)
(bidi-range #xFE20 #xFE2D    'bidi-nsm)
(bidi-range #x101FD         'bidi-nsm)
(bidi-range #x102E0         'bidi-nsm)
(bidi-range #x10376 #x1037A  'bidi-nsm)
(bidi-range #x10A01 #x10A03  'bidi-nsm)
(bidi-range #x10A05 #x10A06  'bidi-nsm)
(bidi-range #x10A0C #x10A0F  'bidi-nsm)
(bidi-range #x10A38 #x10A3A  'bidi-nsm)
(bidi-range #x10A3F         'bidi-nsm)
(bidi-range #x10AE5 #x10AE6  'bidi-nsm)
(bidi-range #x11001         'bidi-nsm)
(bidi-range #x11038 #x11046  'bidi-nsm)
(bidi-range #x1107F #x11081  'bidi-nsm)
(bidi-range #x110B3 #x110B6  'bidi-nsm)
(bidi-range #x110B9 #x110BA  'bidi-nsm)
(bidi-range #x11100 #x11102  'bidi-nsm)
(bidi-range #x11127 #x1112B  'bidi-nsm)
(bidi-range #x1112D #x11134  'bidi-nsm)
(bidi-range #x11173         'bidi-nsm)
(bidi-range #x11180 #x11181  'bidi-nsm)
(bidi-range #x111B6 #x111BE  'bidi-nsm)
(bidi-range #x1122F #x11231  'bidi-nsm)
(bidi-range #x11234         'bidi-nsm)
(bidi-range #x11236 #x11237  'bidi-nsm)
(bidi-range #x112DF         'bidi-nsm)
(bidi-range #x112E3 #x112EA  'bidi-nsm)
(bidi-range #x11301         'bidi-nsm)
(bidi-range #x1133C         'bidi-nsm)
(bidi-range #x11340         'bidi-nsm)
(bidi-range #x11366 #x1136C  'bidi-nsm)
(bidi-range #x11370 #x11374  'bidi-nsm)
(bidi-range #x114B3 #x114B8  'bidi-nsm)
(bidi-range #x114BA         'bidi-nsm)
(bidi-range #x114BF #x114C0  'bidi-nsm)
(bidi-range #x114C2 #x114C3  'bidi-nsm)
(bidi-range #x115B2 #x115B5  'bidi-nsm)
(bidi-range #x115BC #x115BD  'bidi-nsm)
(bidi-range #x115BF #x115C0  'bidi-nsm)
(bidi-range #x11633 #x1163A  'bidi-nsm)
(bidi-range #x1163D         'bidi-nsm)
(bidi-range #x1163F #x11640  'bidi-nsm)
(bidi-range #x116AB         'bidi-nsm)
(bidi-range #x116AD         'bidi-nsm)
(bidi-range #x116B0 #x116B5  'bidi-nsm)
(bidi-range #x116B7         'bidi-nsm)
(bidi-range #x16AF0 #x16AF4  'bidi-nsm)
(bidi-range #x16B30 #x16B36  'bidi-nsm)
(bidi-range #x16F8F #x16F92  'bidi-nsm)
(bidi-range #x1BC9D #x1BC9E  'bidi-nsm)
(bidi-range #x1D167 #x1D169  'bidi-nsm)
(bidi-range #x1D17B #x1D182  'bidi-nsm)
(bidi-range #x1D185 #x1D18B  'bidi-nsm)
(bidi-range #x1D1AA #x1D1AD  'bidi-nsm)
(bidi-range #x1D242 #x1D244  'bidi-nsm)
(bidi-range #x1E8D0 #x1E8D6  'bidi-nsm)
(bidi-range #xE0100 #xE01EF  'bidi-nsm)
(bidi-range #x0608          'bidi-al)
(bidi-range #x060B          'bidi-al)
(bidi-range #x060D          'bidi-al)
(bidi-range #x061B          'bidi-al)
(bidi-range #x061C          'bidi-al)
(bidi-range #x061D          'bidi-al)
(bidi-range #x061E #x061F    'bidi-al)
(bidi-range #x0620 #x063F    'bidi-al)
(bidi-range #x0640          'bidi-al)
(bidi-range #x0641 #x064A    'bidi-al)
(bidi-range #x066D          'bidi-al)
(bidi-range #x066E #x066F    'bidi-al)
(bidi-range #x0671 #x06D3    'bidi-al)
(bidi-range #x06D4          'bidi-al)
(bidi-range #x06D5          'bidi-al)
(bidi-range #x06E5 #x06E6    'bidi-al)
(bidi-range #x06EE #x06EF    'bidi-al)
(bidi-range #x06FA #x06FC    'bidi-al)
(bidi-range #x06FD #x06FE    'bidi-al)
(bidi-range #x06FF          'bidi-al)
(bidi-range #x0700 #x070D    'bidi-al)
(bidi-range #x070E          'bidi-al)
(bidi-range #x070F          'bidi-al)
(bidi-range #x0710          'bidi-al)
(bidi-range #x0712 #x072F    'bidi-al)
(bidi-range #x074B #x074C    'bidi-al)
(bidi-range #x074D #x07A5    'bidi-al)
(bidi-range #x07B1          'bidi-al)
(bidi-range #x07B2 #x07BF    'bidi-al)
(bidi-range #x08A0 #x08B2    'bidi-al)
(bidi-range #x08B3 #x08E3    'bidi-al)
(bidi-range #xFB50 #xFBB1    'bidi-al)
(bidi-range #xFBB2 #xFBC1    'bidi-al)
(bidi-range #xFBC2 #xFBD2    'bidi-al)
(bidi-range #xFBD3 #xFD3D    'bidi-al)
(bidi-range #xFD40 #xFD4F    'bidi-al)
(bidi-range #xFD50 #xFD8F    'bidi-al)
(bidi-range #xFD90 #xFD91    'bidi-al)
(bidi-range #xFD92 #xFDC7    'bidi-al)
(bidi-range #xFDC8 #xFDCF    'bidi-al)
(bidi-range #xFDF0 #xFDFB    'bidi-al)
(bidi-range #xFDFC          'bidi-al)
(bidi-range #xFDFE #xFDFF    'bidi-al)
(bidi-range #xFE70 #xFE74    'bidi-al)
(bidi-range #xFE75          'bidi-al)
(bidi-range #xFE76 #xFEFC    'bidi-al)
(bidi-range #xFEFD #xFEFE    'bidi-al)
(bidi-range #x1EE00 #x1EE03  'bidi-al)
(bidi-range #x1EE04         'bidi-al)
(bidi-range #x1EE05 #x1EE1F  'bidi-al)
(bidi-range #x1EE20         'bidi-al)
(bidi-range #x1EE21 #x1EE22  'bidi-al)
(bidi-range #x1EE23         'bidi-al)
(bidi-range #x1EE24         'bidi-al)
(bidi-range #x1EE25 #x1EE26  'bidi-al)
(bidi-range #x1EE27         'bidi-al)
(bidi-range #x1EE28         'bidi-al)
(bidi-range #x1EE29 #x1EE32  'bidi-al)
(bidi-range #x1EE33         'bidi-al)
(bidi-range #x1EE34 #x1EE37  'bidi-al)
(bidi-range #x1EE38         'bidi-al)
(bidi-range #x1EE39         'bidi-al)
(bidi-range #x1EE3A         'bidi-al)
(bidi-range #x1EE3B         'bidi-al)
(bidi-range #x1EE3C #x1EE41  'bidi-al)
(bidi-range #x1EE42         'bidi-al)
(bidi-range #x1EE43 #x1EE46  'bidi-al)
(bidi-range #x1EE47         'bidi-al)
(bidi-range #x1EE48         'bidi-al)
(bidi-range #x1EE49         'bidi-al)
(bidi-range #x1EE4A         'bidi-al)
(bidi-range #x1EE4B         'bidi-al)
(bidi-range #x1EE4C         'bidi-al)
(bidi-range #x1EE4D #x1EE4F  'bidi-al)
(bidi-range #x1EE50         'bidi-al)
(bidi-range #x1EE51 #x1EE52  'bidi-al)
(bidi-range #x1EE53         'bidi-al)
(bidi-range #x1EE54         'bidi-al)
(bidi-range #x1EE55 #x1EE56  'bidi-al)
(bidi-range #x1EE57         'bidi-al)
(bidi-range #x1EE58         'bidi-al)
(bidi-range #x1EE59         'bidi-al)
(bidi-range #x1EE5A         'bidi-al)
(bidi-range #x1EE5B         'bidi-al)
(bidi-range #x1EE5C         'bidi-al)
(bidi-range #x1EE5D         'bidi-al)
(bidi-range #x1EE5E         'bidi-al)
(bidi-range #x1EE5F         'bidi-al)
(bidi-range #x1EE60         'bidi-al)
(bidi-range #x1EE61 #x1EE62  'bidi-al)
(bidi-range #x1EE63         'bidi-al)
(bidi-range #x1EE64         'bidi-al)
(bidi-range #x1EE65 #x1EE66  'bidi-al)
(bidi-range #x1EE67 #x1EE6A  'bidi-al)
(bidi-range #x1EE6B         'bidi-al)
(bidi-range #x1EE6C #x1EE72  'bidi-al)
(bidi-range #x1EE73         'bidi-al)
(bidi-range #x1EE74 #x1EE77  'bidi-al)
(bidi-range #x1EE78         'bidi-al)
(bidi-range #x1EE79 #x1EE7C  'bidi-al)
(bidi-range #x1EE7D         'bidi-al)
(bidi-range #x1EE7E         'bidi-al)
(bidi-range #x1EE7F         'bidi-al)
(bidi-range #x1EE80 #x1EE89  'bidi-al)
(bidi-range #x1EE8A         'bidi-al)
(bidi-range #x1EE8B #x1EE9B  'bidi-al)
(bidi-range #x1EE9C #x1EEA0  'bidi-al)
(bidi-range #x1EEA1 #x1EEA3  'bidi-al)
(bidi-range #x1EEA4         'bidi-al)
(bidi-range #x1EEA5 #x1EEA9  'bidi-al)
(bidi-range #x1EEAA         'bidi-al)
(bidi-range #x1EEAB #x1EEBB  'bidi-al)
(bidi-range #x1EEBC #x1EEEF  'bidi-al)
(bidi-range #x1EEF2 #x1EEFF  'bidi-al)
(bidi-range #x202D          'bidi-lro)
(bidi-range #x202E          'bidi-rlo)
(bidi-range #x202A          'bidi-lre)
(bidi-range #x202B          'bidi-rle)
(bidi-range #x202C          'bidi-pdf)
(bidi-range #x2066          'bidi-lri)
(bidi-range #x2067          'bidi-rli)
(bidi-range #x2068          'bidi-fsi)
(bidi-range #x2069          'bidi-pdi)

(fmakunbound 'bidi-range)
